try_control

Macro try_control 

macro_rules! try_control {
    ($e:expr, $p:stmt) => { ... };
    ($e:expr, $p:stmt, $q:stmt) => { ... };
}
Return if the expression is a break value, execute the provided statement if it is a prune value.